<template>
  <div class="machine-startup-rate">
    <div class="bar-contents">
      <div class="top-view">
        <img src="/cockpitPage/machine-top.png" alt="" />
        <div class="top-title">
          <span>机器开机率</span>
          <span class="top-rate">{{ startupRate + "%" }}</span>
        </div>
      </div>
      <div id="main" class="chart" ref="chart"></div>
    </div>
  </div>
</template>

<script>
//引入echart
import * as echarts from "echarts";
let myChart;
export default {
  components: {},
  props: {
    startupRate: {
      type: String,
      default: "",
    },
  },
  data() {
    return {};
  },
  mounted() {},
  watch: {},
  methods: {
    //在职
    pieChart(chartName, data) {
      let chartDom = this.$refs[chartName];

      if (myChart != null && myChart != "" && myChart != undefined) {
        myChart.dispose(); //销毁
      }
      myChart = echarts.init(chartDom);
      let img = "/cockpitPage/machine-chart-bg.png";
      let height = myChart.getHeight() / 1;
      let width = height + 5;
      let option;
      if (data) {
        option = {
          color: ["#065a6f", "#067687", "#00ffff"],
          tooltip: {
            trigger: "item",
            textStyle: {
              color: "#00FFFF",
            },
            borderColor: "#00FFFF",
            backgroundColor: "#238d8d6b",
            valueFormatter: function (value) {
              return value + "%";
            },
          },
          graphic: {
            elements: [
              {
                type: "image",
                // z: 5,
                style: {
                  image: img,
                  width: width,
                  height: height,
                  opacity: 0.55,
                },
                left: "center",
                top: "center",
                position: [10, 10],
              },
            ],
          },
          series: [
            {
              name: "Access From",
              type: "pie",
              radius: ["58%", "70%"],
              avoidLabelOverlap: false,
              label: {
                normal: {
                  position: "outer",
                  padding: [0, -62],
                  color: "#01f7fd",
                  fontSize: 12,
                  borderWidth: 5,
                  borderRadius: 4,
                  formatter: function (params) {
                    let label =
                      params.name.length > 4
                        ? `${params.name.slice(0, 3)}...`
                        : params.name;
                    return `{a|${label}} {b|${params.value + "%"}}`;
                  },
                  rich: {
                    a: {
                      color: "#00ffff",
                      fontSize: 14,
                    },
                    b: {
                      color: "#fccd1d",
                      fontSize: 14,
                    },
                  },
                },
              },
              emphasis: {
                label: {
                  show: true,
                  fontSize: 16,
                  fontWeight: "bold",
                },
              },
              labelLine: {
                show: true,
                length: 40,
                color: "blue",
                length2: 70,
              },
              labelLayout: {
                verticalAlign: "bottom",
                dy: -5,
              },
              data: data,
            },
          ],
        };

        option && myChart.setOption(option);
      } else {
        option = {};
        myChart.setOption(option, true);
      }
    },
  },
};
</script>

<style scoped lang="scss">
.machine-startup-rate {
  width: 100%;
  height: 100%;
  .bar-contents {
    width: calc(100% - 20px);
    height: 100%;
    border: 1px solid #00ffff;
    box-sizing: border-box;
    position: relative;
    .top-view {
      width: 33%;
      margin-top: -1px;
      margin-left: -1px;
      position: relative;
      text-align: center;
      .top-title {
        width: 100%;
        position: absolute;
        top: 20%;
        left: 0;
        margin: auto;
        color: #01f7fd;
        font-size: 14px;
        font-family: "Arial Negreta", "Arial Normal", "Arial";
        font-weight: 700;
        .top-rate {
          margin-left: 5px;
          color: #fec718;
        }
      }
    }
    .chart {
      margin-top: 8px;
      margin-left: 5px;
      width: 100%;
      height: calc(80% - 20px);
    }
  }
}
</style>
